==> qupzilla-1.8.7-1-src.tar.xz: qupzilla-1.8.7/src/plugins/FlashCookieManager/translations/he_IL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.0">
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>עוגיות Flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>עוגיות Flash מאוחסנות</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>מצא:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="149"/>
        <location filename="../fcm_dialog.cpp" line="150"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;עוגיית flash לא נבחרה&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>שונתה לאחרונה:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="275"/>
        <location filename="../fcm_dialog.cpp" line="290"/>
        <source>Origin:</source>
        <translation>מוצא:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>מחרוזות latin1 מחולצות:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>עוגיות flash אלו מאוחסנות בתוך המחשב שלך:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>מוצא</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>טען מתוך כונן</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>נתיב:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>לחץ כדי לפתוח תיקייה מכילה</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>הסר את כל עוגיות flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>Remove flash cookies</source>
        <translation>הסר עוגיות flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>סינון עוגיות Flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;רשימה לבנה של עוגיות Flash&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>הסר</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;רשימה שחורה של עוגיות Flash&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הגדרות עוגיית Flash&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>מחק כל עוגיית flash בעת יציאה/עלייה. (חוץ מאלה שברשימה לבנה)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="579"/>
        <source>Flash data path*:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="595"/>
        <source>Browse...</source>
        <translation>עיון...</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="617"/>
        <source>*: You should select directory that contains #SharedObject as a subfolder.</source>
        <translation>*: עליך לבחור מדור אשר מכיל SharedObject# בתור תיקיית משנה.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="77"/>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="91"/>
        <source>Confirmation</source>
        <translation>אימות</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="92"/>
        <source>Are you sure to delete all flash cookies on your computer?</source>
        <translation>האם אתה בטוח כי ברצונך למחוק את כל עוגיות flash מתוך המחשב שלך?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="164"/>
        <location filename="../fcm_dialog.cpp" line="235"/>
        <source> (settings)</source>
        <translation> (הגדרות)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="167"/>
        <source> Byte</source>
        <translation>בית</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="173"/>
        <source>Remove flash cookie</source>
        <translation>הסר עוגיית flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="239"/>
        <source> [new]</source>
        <translation>[חדש]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="275"/>
        <source>Add to whitelist</source>
        <translation>הוסף אל רשימה לבנה</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="290"/>
        <source>Add to blacklist</source>
        <translation>הוסף אל רשימה שחורה</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="345"/>
        <source>Select Flash Data Path</source>
        <translation>בחר נתיב נתוני Flash</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>עוגיית flash חדשה אותרה!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>הצג</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>עוגיית flash חדשה אותרה</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>%1 עוגיוית flash חדשות אותרו</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="353"/>
        <source>Show/Hide Flash Cookie Manager</source>
        <translation>הצג/הסתר מנהל עוגיות Flash</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="439"/>
        <source>!default</source>
        <translation>!ברירת מחדל</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="451"/>
        <source>!other</source>
        <translation>!אחר</translation>
    </message>
</context>
</TS>

==> qupzilla-1.8.9-2-src.tar.xz: qupzilla-1.8.9/src/plugins/FlashCookieManager/translations/he_IL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.0">
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>עוגיות Flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>עוגיות Flash מאוחסנות</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>מצא:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="149"/>
        <location filename="../fcm_dialog.cpp" line="150"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;עוגיית flash לא נבחרה&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>שונתה לאחרונה:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="275"/>
        <location filename="../fcm_dialog.cpp" line="290"/>
        <source>Origin:</source>
        <translation>מוצא:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>מחרוזות latin1 מחולצות:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>עוגיות flash אלו מאוחסנות בתוך המחשב שלך:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>מוצא</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>טען מתוך כונן</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>נתיב:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>לחץ כדי לפתוח תיקייה מכילה</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>הסר את כל עוגיות flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>Remove flash cookies</source>
        <translation>הסר עוגיות flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>סינון עוגיות Flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;רשימה לבנה של עוגיות Flash&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>הסר</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;רשימה שחורה של עוגיות Flash&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>עוגיות Flash מתוך מקורות אלו יימחקו בלי כל התראה.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הגדרות עוגיית Flash&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הערה:&lt;/span&gt; הגדרות אלה חלות על עוגיות פלאש, כדי לנהל עוגיות HTTP השתמש בדו שיח &lt;span style=&quot; font-weight:600;&quot;&gt;מנהל עוגיות&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>מחק כל עוגיית flash בעת יציאה/עלייה. (חוץ מאלה שברשימה לבנה)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="579"/>
        <source>Flash data path*:</source>
        <translation>נתיב נתוני Flash*:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="595"/>
        <source>Browse...</source>
        <translation>עיון...</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="617"/>
        <source>*: You should select directory that contains #SharedObject as a subfolder.</source>
        <translation>*: עליך לבחור מדור אשר מכיל SharedObject# בתור תיקיית משנה.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="77"/>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="91"/>
        <source>Confirmation</source>
        <translation>אימות</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="92"/>
        <source>Are you sure to delete all flash cookies on your computer?</source>
        <translation>האם אתה בטוח כי ברצונך למחוק את כל עוגיות flash מתוך המחשב שלך?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="164"/>
        <location filename="../fcm_dialog.cpp" line="235"/>
        <source> (settings)</source>
        <translation> (הגדרות)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="167"/>
        <source> Byte</source>
        <translation>בית</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="173"/>
        <source>Remove flash cookie</source>
        <translation>הסר עוגיית flash</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="239"/>
        <source> [new]</source>
        <translation>[חדש]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="275"/>
        <source>Add to whitelist</source>
        <translation>הוסף אל רשימה לבנה</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="290"/>
        <source>Add to blacklist</source>
        <translation>הוסף אל רשימה שחורה</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="345"/>
        <source>Select Flash Data Path</source>
        <translation>בחר נתיב נתוני Flash</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>עוגיית flash חדשה אותרה!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>הצג</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>עוגיית flash חדשה אותרה</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>%1 עוגיוית flash חדשות אותרו</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="353"/>
        <source>Show/Hide Flash Cookie Manager</source>
        <translation>הצג/הסתר מנהל עוגיות Flash</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="439"/>
        <source>!default</source>
        <translation>!ברירת מחדל</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="451"/>
        <source>!other</source>
        <translation>!אחר</translation>
    </message>
</context>
</TS>
